@@ -7,7 +7,7 @@
  * @date   2004-02-01
  * @brief  main kipi host application interface
  *
- * @author Copyright (C) 2004-2015 by Gilles Caulier
+ * @author Copyright (C) 2004-2017 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2006-2012 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -93,7 +93,7 @@ enum Features
     HostSupportsPreviews           = 1 << 16, /** This feature specifies that host application can provide image preview.                                                           */
     HostSupportsRawProcessing      = 1 << 17, /** This feature specifies that host application can process Raw files.                                                               */
     HostSupportsMetadataProcessing = 1 << 18, /** This feature specifies that host application can process Metadata from files.                                                     */
-    HostSupportsSaveImages         = 1 << 19  /** This feature specifies that host application can save image files           .                                                     */
+    HostSupportsSaveImages         = 1 << 19  /** This feature specifies that host application can save image files.                                                                */
 };
 
 // NOTE: When a new item is add to Features, please don't forget to patch Interface::hasFeature().
@@ -161,41 +161,6 @@ public:
 
 // ---------------------------------------------------------------------------------------------------------------
 
-/**
- *  A Kipi RawProcessor refers to application-wide to process Raw file 
- *  about preview extraction or demosicing; it is created with Interface::createRawProcessor()
- *  You can use libkdcraw to re-implement this class as it's implemented in tests/common/kipiinterface.cpp.
- */
-class LIBKIPI_EXPORT RawProcessor : public QObject
-{
-public:
-
-    RawProcessor()          {};
-    virtual ~RawProcessor() {};
-
-    /** To perform Raw preview extraction.
-     */
-    virtual bool loadRawPreview(const QUrl& url, QImage& image) = 0;
-
-    /** To perform demosiacing. Can be cancelled.
-     */
-    virtual bool decodeRawImage(const QUrl& url, QByteArray& imageData, int& width, int& height, int& rgbmax) = 0;
-
-    /** To cancel decodeRawImage() processing.
-     */
-    virtual void cancel() = 0;
-
-    /** Rteun true if url is a Raw file, else false
-     */
-    virtual bool isRawFile(const QUrl& url) = 0;
-
-    /** Return the list of all RAW file type mime supported by the decoder.
-     */
-    virtual QString rawFiles() = 0;
-};
-
-// ---------------------------------------------------------------------------------------------------------------
-
 /**
  *  A Kipi MetadataProcessor refers to application-wide to process file metadata
  *  about Exif/Iptc/Xmp management; it is created with Interface::createMetadataProcessor().
@@ -350,10 +315,10 @@ public:
     virtual void refreshImages(const QList<QUrl>&);
 
     /**
-     * Tells to host application to render imediatly a preview image for one item at mininimum size.
+     * Tells to host application to render imediatly a preview image for one item.
      * This method re-implemented in host application and be thread safe.
      */
-    virtual QImage preview(const QUrl& url, int minSize);
+    virtual QImage preview(const QUrl& url);
 
     /**
      * Tell to host application to save image at url in specific format (JPG, PNG, TIF, etc).
@@ -368,13 +333,13 @@ public:
                            bool* cancel=0);
 
     /**
-     * Tells to host application to render a preview image for one item at mininimum size.
+     * Tells to host application to render a preview image for one item.
      * A resizement to to a specific size will be generated if preview is largest than.
-     * Use a positive resizedTo value in this case. Aspect ratio is preserved while rendering. 
+     * Use a positive resizedTo value in this case, else -1. Aspect ratio is preserved while rendering.
      * This asynchronous method must be re-implemented in host application.
      * Use gotPreview() signal to take preview.
      */
-    virtual void preview(const QUrl& url, int minSize, int resizedTo=-1);
+    virtual void preview(const QUrl& url, int resizedTo);
 
     /**
      * Tells to host application to render a thumbnail for one item. This asynchronous method must be
@@ -389,7 +354,7 @@ public:
     virtual void thumbnails(const QList<QUrl>& list, int size);
 
     /**
-      Ask to Kipi host application to prepare progress manager for a new entry. This method must return from host 
+      Ask to Kipi host application to prepare progress manager for a new entry. This method must return from host
       a string identification about progress item created. This id will be used later to change in host progress item
       value and text. Title is text used to name progress item in host application.
       Set canBeCanceled to true if you want that progress item provide a cancel button to close process from kipi host.
@@ -411,42 +376,9 @@ public:
     virtual void progressThumbnailChanged(const QString& id, const QPixmap& thumb);
     virtual void progressCompleted(const QString& id);
 
-    /*!
-      \brief Tells to host application to return a setting to share with plugins.
-
-      <table><tr>
-            <th>SETTING NAME</th>
-            <th>VALUE RETURNED</th>
-            <th>COMMENTS</th>
-        </tr><tr>
-            <th>"FileExtensions"</th>
-            <td>QString</td>
-            <td>Returns all file extensions (image, sound, video) managed by host application, separated by blank spaces, (ex: "JPG PNG TIF NEF AVI MP3").</td>
-        </tr><tr>
-            <th>"ImagesExtensions"</th>
-            <td>QString</td>
-            <td>Returns images file extensions managed by host application, not incuding RAW formats, separated by blank spaces, (ex: "JPG PNG TIF").</td>
-        </tr><tr>
-            <th>"RawExtensions"</th>
-            <td>QString</td>
-            <td>Returns RAW file extensions managed by host application, separated by blank spaces, (ex: "NEF CR2 ARW PEF").</td>
-        </tr><tr>
-            <th>"VideoExtensions"</th>
-            <td>QString</td>
-            <td>Returns video file extensions managed by host application, separated by blank spaces, (ex: "AVI MOV MPG").</td>
-        </tr><tr>
-            <th>"AudioExtensions"</th>
-            <td>QString</td>
-            <td>Return audio file extensions managed by host application, separated by blank spaces, (ex: "MP3 WAV OGG").</td>
-      </tr></table>
-
-      This method return the default settings. Re-implement this method in your dedicated kipi interface
-      to control kipi-plugins rules with your kipi host application settings.
-
-      NOTE: If you want to manage host settings from kipi-plugins, use wrapper class KIPIPlugins::KPHostSettings,
-      not this method directly.
+    /** Returns RAW file extensions managed by host application, separated by blank spaces, (ex: "NEF CR2 ARW PEF").</td>
     */
-    virtual QVariant hostSetting(const QString& settingName);
+    virtual QString rawFiles();
 
     virtual ImageCollectionSelector* imageCollectionSelector(QWidget* parent)=0;
     virtual UploadWidget*            uploadWidget(QWidget* parent)=0;
@@ -474,7 +406,7 @@ public:
      * Clears a reservation made previously with reserveForAction for the given reservingObject.
      * You must clear any reservation you made, or, alternatively, delete the reserving object.
      */
-    virtual void clearReservation(const QUrl &url, QObject* const reservingObject);
+    virtual void clearReservation(const QUrl& url, QObject* const reservingObject);
 
     /**
      * Supported if HostSupportsItemReservation
@@ -482,7 +414,7 @@ public:
      * Returns if the item is reserved. You can pass a pointer to a QString; if the return value
      * is true, the string will be set to the descriptionOfAction set with reserveForAction.
      */
-    virtual bool itemIsReserved(const QUrl &url, QString* const descriptionOfAction = 0) const;
+    virtual bool itemIsReserved(const QUrl& url, QString* const descriptionOfAction = 0) const;
 
     /**
      * Supported if HostSupportsReadWriteLock
@@ -492,15 +424,7 @@ public:
      * The implementation from KIPI host application must be thread-safe.
      *
      */
-    virtual FileReadWriteLock* createReadWriteLock(const QUrl& url) const = 0;
-
-    /**
-     * Supported if HostSupportsRawProcessing.
-     * Creates an instance of RawProcessor dedicated to process Raw files.
-     * The implementation from KIPI host application must be thread-safe.
-     *
-     */
-    virtual RawProcessor* createRawProcessor() const = 0;
+    virtual FileReadWriteLock* createReadWriteLock(const QUrl& url) const;
 
     /**
      * Supported if HostSupportsMetadataProcessing.
@@ -508,8 +432,8 @@ public:
      * The implementation from KIPI host application must be thread-safe.
      *
      */
-    virtual MetadataProcessor* createMetadataProcessor() const = 0;
-    
+    virtual MetadataProcessor* createMetadataProcessor() const;
+
     /**
      * Supported if HostSupportsEditHints
      *
@@ -542,12 +466,12 @@ Q_SIGNALS:
     void selectionChanged(bool hasSelection);
 
     /**
-     * Emit when current album selection as changed from host application user interface. 
+     * Emit when current album selection as changed from host application user interface.
      * Boolean argument is true if album are select or not in collection.
      */
     void currentAlbumChanged(bool hasSelection);
 
-    /** Emit when host application has rendered item thumbnail. See asynchronous thumbnail() and thumbnails() 
+    /** Emit when host application has rendered item thumbnail. See asynchronous thumbnail() and thumbnails()
      *  methods for details.
      */
     void gotThumbnail(const QUrl&, const QPixmap&);
@@ -566,8 +490,8 @@ Q_SIGNALS:
      *
      * Emitted from reservedForAction and clearReservation, respectively.
      * */
-    void reservedForAction(const QUrl &url, const QString& descriptionOfAction);
-    void reservationCleared(const QUrl &url);
+    void reservedForAction(const QUrl& url, const QString& descriptionOfAction);
+    void reservationCleared(const QUrl& url);
 
 protected:
 
